RowGroup example - Ajax with objects

# RowGroup example Ajax with objects

The majority of the RowGroup examples make use of an array data source since they are reading data from an HTML table. However, it is quite possible to make use of objects as well, and in fact this often makes the most sense when using row grouping, since it is easy to identify the data point to use for grouping.

This example demonstrates Ajax loading of object based data for the table, with the `rowGroup.dataSrc` option used to group by the Office column.

Name | Position | Office | Extn. | Start date | Salary
--- | --- | --- | --- | --- | ---
Name | Position | Office | Extn. | Start date | Salary

- Javascript
- HTML
- CSS
- Ajax
- Server-side script

The Javascript shown below is used to initialise the table shown in this example:

`$(document).ready(function() { $('#example').DataTable( { ajax: '../../../../examples/ajax/data/objects.txt', columns: [ { data: 'name' }, { data: 'position' }, { data: 'office' }, { data: 'extn' }, { data: 'start_date' }, { data: 'salary' } ], order: [[2, 'asc']], rowGroup: { dataSrc: 'office' } } ); } );`

In addition to the above code, the following Javascript library files are loaded for use in this example:

- //code.jquery.com/jquery-1.12.4.js
- ../../../../media/js/jquery.dataTables.js
- ../../js/dataTables.rowGroup.js

The HTML shown below is the raw HTML table element, before it has been enhanced by DataTables:

This example uses a little bit of additional CSS beyond what is loaded from the library files (below), in order to correctly display the table. The additional CSS used is shown below:

``

The following CSS library files are loaded for use in this example to provide the styling of the table:

- ../../../../media/css/jquery.dataTables.css
- ../../css/rowGroup.dataTables.css

This table loads data by Ajax. The latest data that has been loaded is shown below. This data will update automatically as any additional data is loaded.

The script used to perform the server-side processing for this table is shown below. Please note that this is just an example script using PHP. Server-side processing scripts can be written in any language, using the protocol described in the DataTables documentation.